@@ -99,6 +99,7 @@ _service_ports: Dict[str, int] = {
     "servicediscovery": 4630,
     "serverlessrepo": 4631,
     "appconfig": 4632,
+    "appconfigdata": 4632,
     "ce": 4633,
     "mediaconvert": 4634,
     "resourcegroupstaggingapi": 4635,
@@ -119,6 +120,8 @@ _service_ports: Dict[str, int] = {
     "appflow": 4566,
     "route53domains": 4566,
     "keyspaces": 4566,
+    "scheduler": 4566,
+    "ram": 4566,
 }
 
 # TODO remove service port mapping above entirely
